"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.default = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _ = _interopRequireWildcard(require("lodash"));

var _2 = require("./..");

/**
 * @category controls
 * @component activity-button
 * @variations collab-ui-react
 */
var ActivityButton = function ActivityButton(props) {
  var type = props.type,
      large = props.large,
      onClick = props.onClick,
      disabled = props.disabled,
      className = props.className,
      ariaLabel = props.ariaLabel,
      otherHTMLProps = (0, _objectWithoutProperties2.default)(props, ["type", "large", "onClick", "disabled", "className", "ariaLabel"]);
  return _react.default.createElement(_2.Button, (0, _extends2.default)({
    className: 'cui-activity' + ("" + (!type.icon && " cui-activity__" + type || '')) + ("" + (large && ' cui-activity--large' || '')) + ("" + (className && " " + className || '')),
    circle: true,
    disabled: disabled,
    onClick: onClick,
    ariaLabel: ariaLabel || !type.icon && type || '',
    color: _.get(type, 'color')
  }, large && {
    containerLarge: true
  }, otherHTMLProps), type.icon ? type.icon : _react.default.createElement(_2.Icon, {
    name: "" + type + (large ? '_36' : '_28')
  }));
};

ActivityButton.displayName = 'ActivityButton';
ActivityButton.propTypes = {
  /**
   *  activity prop type
   */
  type: _propTypes.default.oneOfType([_propTypes.default.oneOf(['chat', 'camera', 'meetings', 'whiteboard', 'files', 'share-screen', 'tasks']), _propTypes.default.shape({
    color: _propTypes.default.string,
    icon: _propTypes.default.element.isRequired
  })]).isRequired,

  /**
   * Handler to be called when the user taps the button
   */
  onClick: _propTypes.default.func,

  /**
   * @ignore
   * optional css class string
   */
  className: _propTypes.default.string,

  /**
   * Sets the attribute disabled to the button
   */
  disabled: _propTypes.default.bool,

  /**
   * Sets the large attribute to the button
   */
  large: _propTypes.default.bool,

  /**
   * Text to display for blindness accessibility features
   */
  ariaLabel: _propTypes.default.string
};
ActivityButton.defaultProps = {
  type: '',
  large: false,
  onClick: null,
  className: '',
  disabled: false,
  ariaLabel: ''
};
var _default = ActivityButton;
/**
* @name Default Activity Button
* @description Default Activity Button.
*
* @category controls
* @component activity-button
* @section default
*
* @js

export default function ActivityButtonDefault() {
  return(
    <div className='row' style={{marginBottom: '1rem'}}>
      <div>Default</div>
      <div style={{margin: `16px`}}>
        <ActivityButton
          type='chat'
          ariaLabel='jlshjksfghjl'
          onClick={()=>{}}
          label='Chat'
        />
        <ActivityButton
          type='camera'
          onClick={()=>{}}
          label='Camera'
        />
        <ActivityButton
          type='meetings'
          onClick={()=>{}}
          label='Meetings'
        />
        <ActivityButton
          type='whiteboard'
          onClick={()=>{}}
          label='Whiteboard'
        />
        <ActivityButton
          type='files'
          onClick={()=>{}}
          label='Files'
        />
        <ActivityButton
          type='share-screen'
          onClick={()=>{}}
          label='Share'
        />
        <ActivityButton
          type='tasks'
          onClick={()=>{}}
          label='Tasks'
        />
      </div>
    </div>
  );
}

**/

/**
* @name ActivityButton with large
* @description ActivityButton with large class.
*
* @category controls
* @component activity-button
* @section large
*
* @js

export default function ActivityButtonLarge() {
  return(
    <div className='row' style={{marginBottom: '1rem'}}>
      <div>Default</div>
      <div style={{margin: `16px`}}>
        <ActivityButton
          type='chat'
          large
          onClick={()=>{}}
          label='Chat'
          ariaLabel='Chat'
        />
        <ActivityButton
          type='camera'
          large
          onClick={()=>{}}
          label='Camera'
          ariaLabel='Camera'
        />
        <ActivityButton
          type='meetings'
          large
          onClick={()=>{}}
          label='Meetings'
          ariaLabel='Meetings'
        />
        <ActivityButton
          type='whiteboard'
          large
          onClick={()=>{}}
          label='Whiteboard'
          ariaLabel='Whiteboard'
        />
        <ActivityButton
          type='files'
          large
          onClick={()=>{}}
          label='Files'
          ariaLabel='Files'
        />
        <ActivityButton
          type='share-screen'
          large
          onClick={()=>{}}
          label='Share'
          ariaLabel='Share'
        />
        <ActivityButton
          type='tasks'
          large
          onClick={()=>{}}
          label='Tasks'
          ariaLabel='Tasks'
        />
      </div>
    </div>
  );
}

**/

/**
* @name ActivityButton with custom
* @description ActivityButton with custom prop.
*
* @category controls
* @component activityButton
* @section custom
*
* @js

export default function ActivityButtonCustom() {
  return(
    <div className='row' style={{marginBottom: '1rem'}}>
      <div>Default</div>
      <div style={{margin: `16px`}}>
        <ActivityButton
          type={{
            color: 'mint',
            icon: <span className='icon icon-arrow-left_32'/>
          }}
          large
          onClick={()=>{}}
          ariaLabel='Left Arrow'
        />
        <ActivityButton
          type={{
            color: 'red',
            icon: <span className='icon icon-keyboard_16'/>
          }}
          onClick={()=>{}}
          ariaLabel='Keyboard'
        />
      </div>
    </div>
  );
}

**/

exports.default = _default;
module.exports = exports["default"];