"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.default = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _inheritsLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/inheritsLoose"));

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _ = require("./..");

/**
 * @category controls
 * @component call-control
 * @variations collab-ui-react
 */
var CallControl =
/*#__PURE__*/
function (_React$PureComponent) {
  function CallControl() {
    return _React$PureComponent.apply(this, arguments) || this;
  }

  var _proto = CallControl.prototype;

  _proto.render = function render() {
    var _this$props = this.props,
        active = _this$props.active,
        type = _this$props.type,
        onClick = _this$props.onClick,
        disabled = _this$props.disabled,
        className = _this$props.className,
        ariaLabel = _this$props.ariaLabel,
        otherHTMLProps = (0, _objectWithoutProperties2.default)(_this$props, ["active", "type", "onClick", "disabled", "className", "ariaLabel"]);
    return _react.default.createElement(_.Button, (0, _extends2.default)({
      className: 'cui-call-control' + ("" + (type === 'cancel' && " cui-call-control--cancel" || '')) + ("" + (active && " cui-call-control--active" || '')) + ("" + (className && " " + className || '')),
      circle: true,
      disabled: disabled,
      onClick: onClick,
      ariaLabel: ariaLabel || type
    }, otherHTMLProps), _react.default.createElement(_.Icon, {
      name: type + "_24"
    }));
  };

  (0, _inheritsLoose2.default)(CallControl, _React$PureComponent);
  return CallControl;
}(_react.default.PureComponent);

CallControl.displayName = 'CallControl';
CallControl.propTypes = {
  /**
   * optional call control prop type
   */
  type: _propTypes.default.oneOf(['microphone-muted', 'cancel', 'camera-muted', 'share-screen', 'speaker']),

  /**
   * Handler to be called when the user taps the button
   */
  onClick: _propTypes.default.func,

  /**
   * @ignore
   * optional css class string
   */
  className: _propTypes.default.string,

  /**
   * Sets the attribute disabled to the button
   */
  disabled: _propTypes.default.bool,

  /**
   * Sets the active state for the button
   */
  active: _propTypes.default.bool,

  /**
   * Text to display for blindness accessibility features
   */
  ariaLabel: _propTypes.default.string
};
CallControl.defaultProps = {
  type: '',
  onClick: null,
  className: '',
  disabled: false,
  active: false,
  ariaLabel: ''
};
var _default = CallControl;
/**
* @name Default Call-Control
* @description Default Call-Control.
*
* @category controls
* @component call-control
* @section default
*
* @js

export default function CallControlDefault() {
  return(
    <div className='row' style={{marginBottom: '1rem'}}>
      <div>Default</div>
      <div className='columns small-3'>
        <CallControl
          type='microphone-muted'
          ariaLabel='For the Win'
        />
      </div>
    </div>
  );
}

**/

/**
* @name Call-Control with active
* @description Call control with active class.
*
* @category controls
* @component call-control
* @section active
*
* @js

export default function CallControlActive() {
  return(
    <div className='row' style={{marginBottom: '1rem'}}>
      <div>Default</div>
      <div className='columns small-3'>
        <CallControl
          type='microphone-muted'
          active
          onClick={() => {}}
          ariaLabel='For the Win'
        />
      </div>
    </div>
  );
}

**/

/**
* @name Call-Control with disable
* @description Call-Control with disabled class.
*
* @category controls
* @component call-control
* @section disable
*
* @js

export default function CallControlDisabled() {
  return(
    <div className='row' style={{marginBottom: '1rem'}}>
      <div>Default</div>
      <div className='columns small-3'>
        <CallControl
          type='microphone-muted'
          disabled
          onClick={() => {}}
          ariaLabel='For the Win'
        />
      </div>
    </div>
  );
}

**/

/**
* @name Call-Control cancel
* @description Call-Control with cancel class.
*
* @category controls
* @component call-control
* @section cancel
*
* @js

export default function CallControlCancel() {
  return(
    <div className='row' style={{marginBottom: '1rem'}}>
      <div>Default</div>
      <div className='columns small-3'>
        <CallControl
          type='cancel'
          onClick={() => {}}
          ariaLabel='For the Win'
        />
      </div>
    </div>
  );
}

**/

exports.default = _default;
module.exports = exports["default"];