"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.default = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _getIterator2 = _interopRequireDefault(require("@babel/runtime/core-js/get-iterator"));

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _iconsData = _interopRequireDefault(require("@collab-ui/icons/data/iconsData.json"));

var _colors = _interopRequireDefault(require("@collab-ui/core/data/colors.json"));

var _lodash = _interopRequireDefault(require("lodash"));

/**
 * @category styles
 * @component icon
 * @variations collab-ui-react
 */
var count = 0;

var Icon = function Icon(props) {
  var name = props.name,
      size = props.size,
      className = props.className,
      color = props.color,
      title = props.title,
      description = props.description,
      isAria = props.isAria,
      otherHTMLProps = (0, _objectWithoutProperties2.default)(props, ["name", "size", "className", "color", "title", "description", "isAria"]);
  var iconCount = count++;
  var titleId = "icon-title-" + iconCount;
  var descId = description ? "icon-desc-" + iconCount : undefined;

  var consoleHandler = function consoleHandler(message, data) {
    /* eslint-disable no-console */
    switch (message) {
      case 'color-warn':
        console.warn(data + " may not exist in the design system," + " please use a color name from http://collab-ui.cisco.com/styles/colors");
        break;

      case 'color-error':
        throw new Error(data + " does not exist in the design system," + " please use a color name from http://collab-ui.cisco.com/styles/colors");

      case 'name-error':
        throw new Error("Icon " + data + " does not exist in the design system." + " Visit http://collab-ui-icons.cisco.com for a list of available icons or to request a new icon.");
    }
    /* eslint-enable no-console */

  };

  var getSize = function getSize() {
    var defaultSize = 16;
    var sizeFromName = Number(name.split("_")[1]);
    return size || sizeFromName || defaultSize;
  };

  var getColorSpec = function getColorSpec(colorObj) {
    return colorObj.hex ? colorObj.hex : colorObj.opacity && isolateRoot(colorObj.variable) === 'white' ? "rgba(255, 255, 255, " + colorObj.opacity / 100 + ")" : "rgba(0, 0, 0, " + colorObj.opacity / 100 + ")";
  };

  var getHexFromJSON = function getHexFromJSON(colorName) {
    for (var _iterator = _colors.default, _isArray = Array.isArray(_iterator), _i = 0, _iterator = _isArray ? _iterator : (0, _getIterator2.default)(_iterator);;) {
      var _ref;

      if (_isArray) {
        if (_i >= _iterator.length) break;
        _ref = _iterator[_i++];
      } else {
        _i = _iterator.next();
        if (_i.done) break;
        _ref = _i.value;
      }

      var c = _ref;

      var variation = _lodash.default.find(c.variations, ['variable', colorName]);

      if (variation) return getColorSpec(variation);
    }

    return consoleHandler('color-error', colorName);
  };

  var isolateRoot = function isolateRoot(str) {
    return _lodash.default.chain(str).trimStart('$').split('-').value()[0];
  };

  var formatColor = function formatColor() {
    return color.startsWith('$') ? color : color.endsWith('-base') ? _lodash.default.trimEnd(color, '-base') : "$" + color;
  };

  var getColor = function getColor() {
    if (!color) return 'inherit';

    if (color.startsWith('#')) {
      consoleHandler('color-warn', color);
      return color;
    }

    return getHexFromJSON(formatColor());
  };

  var getPaths = function getPaths() {
    var iconName = name.startsWith('icon-') ? _lodash.default.trimStart(name, 'icon-') : name;
    return _iconsData.default[iconName] ? _iconsData.default[iconName].map(function (icoPath, index) {
      return _react.default.createElement("path", {
        d: icoPath,
        key: index
      });
    }) : consoleHandler('name-error', iconName);
  };

  var getAria = function getAria() {
    return description ? titleId + " " + descId : "" + titleId;
  };

  var getTitle = function getTitle() {
    return !title ? _lodash.default.startCase(name) : title;
  };

  return _react.default.createElement("svg", (0, _extends2.default)({
    className: "cui-icon" + ("" + (className && " " + className || '')),
    width: getSize(),
    height: getSize(),
    "aria-labelledby": isAria ? getAria() : undefined
  }, otherHTMLProps), isAria && _react.default.createElement("title", {
    id: titleId
  }, getTitle()), description && isAria && _react.default.createElement("desc", {
    id: descId
  }, description), _react.default.createElement("g", {
    fill: getColor(),
    fillRule: "evenodd"
  }, getPaths()));
};

Icon.propTypes = {
  name: _propTypes.default.string.isRequired,
  size: _propTypes.default.number,
  color: _propTypes.default.string,
  className: _propTypes.default.string,
  isAria: _propTypes.default.bool,
  title: _propTypes.default.string,
  description: _propTypes.default.string
};
Icon.defaultProps = {
  color: '',
  className: '',
  isAria: true
};
Icon.displayName = 'Icon';
var _default = Icon;
exports.default = _default;
module.exports = exports["default"];