"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.default = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _ = _interopRequireWildcard(require("lodash"));

/**
 * @category communication
 * @component loader-spinner
 * @variations collab-ui-react
 */
var Spinner = function Spinner(props) {
  var size = props.size,
      color = props.color,
      className = props.className,
      percentage = props.percentage,
      showPercentage = props.showPercentage,
      otherHTMLProps = (0, _objectWithoutProperties2.default)(props, ["size", "color", "className", "percentage", "showPercentage"]);

  if (_.isNumber(percentage)) {
    if (size !== 36 && showPercentage) {
      /* eslint-disable no-console */
      console.warn('Percentage will not be shown for sizes smaller than 36');
    }

    return _react.default.createElement("div", (0, _extends2.default)({
      className: "cui-spinner-progress" + ("" + (size && " cui-spinner-progress--" + size || '')) + ("" + (color && " cui-spinner-progress--" + color || '')) + ("" + (className && " " + className || '')) + (" cui-spinner-progress__percentage-" + _.round(percentage))
    }, otherHTMLProps), _react.default.createElement("div", {
      className: "cui-spinner-progress__circle"
    }, _react.default.createElement("div", {
      className: "cui-spinner-progress__mask cui-spinner-progress__full"
    }, _react.default.createElement("div", {
      className: "cui-spinner-progress__fill"
    })), _react.default.createElement("div", {
      className: "cui-spinner-progress__mask cui-spinner-progress__half"
    }, _react.default.createElement("div", {
      className: "cui-spinner-progress__fill"
    }), _react.default.createElement("div", {
      className: "cui-spinner-progress__fill cui-spinner-progress__fix"
    })), _react.default.createElement("div", {
      className: "cui-spinner-progress__inset-circle"
    }, size === 36 && showPercentage && _react.default.createElement("div", {
      className: "cui-spinner-progress__percentage"
    }, _.round(percentage)))));
  } else {
    return _react.default.createElement("i", (0, _extends2.default)({
      className: "cui-spinner" + ("" + (size && " cui-spinner--" + size || '')) + ("" + (color && " cui-spinner--" + color || '')) + ("" + (className && " " + className || ''))
    }, otherHTMLProps));
  }
};

Spinner.propTypes = {
  /**
   * css class names
   */
  className: _propTypes.default.string,

  /**
   * size
   */
  size: _propTypes.default.oneOf([16, 20, 28, 36]),

  /**
   * color
   */
  color: _propTypes.default.string,

  /**
   * percentage value to show on progress
   */
  percentage: _propTypes.default.number,

  /**
   * show the number value for progress
   */
  showPercentage: _propTypes.default.bool
};
Spinner.defaultProps = {
  size: 36,
  color: 'black',
  className: '',
  percentage: null,
  showPercentage: false
};
Spinner.displayName = 'Spinner';
var _default = Spinner;
/**
* @name Spinner
* @description Different states of spinners.
*
* @category communication
* @component loader-spinner
* @section states
*
* @js

import {Spinner} from '@collab-ui/react';

export default function Default() {
  return (
    <div>
      <div className="docui-example docui-example--spacing">
        <h3>Default <code className="small">Spinner</code></h3>
        <Spinner />
      </div>
      <div className="docui-example docui-example--spacing">
        <h3>Default <code className="small">Spinner size:20</code></h3>
        <Spinner size={20}/>
      </div>
      <div className="docui-example docui-example--spacing">
        <h3>Default <code className="small">Spinner size:28</code></h3>
        <Spinner size={28}/>
      </div>
      <div className="docui-example docui-example--spacing">
        <h3>Default <code className="small">Spinner size:36</code></h3>
        <Spinner size={36}/>
      </div>
      <div className="docui-example docui-example--spacing">
        <h3>Blue <code className="small">Spinner color:blue</code></h3>
        <Spinner color='blue'/>
      </div>
      <div className="docui-example docui-example--spacing">
        <h3>Blue <code className="small">Spinner color:blue size:20</code></h3>
        <Spinner size={20} color='blue'/>
      </div>
      <div className="docui-example docui-example--spacing">
        <h3>Blue <code className="small">Spinner color:blue size:28</code></h3>
        <Spinner size={28} color='blue'/>
      </div>
      <div className="docui-example docui-example--spacing">
        <h3>Blue <code className="small">Spinner color:blue size:36</code></h3>
        <Spinner size={36} color='blue'/>
      </div>
      <div className="docui-example docui-example--spacing cui--dark docs-example--dark">
        <h3>Dark <code className="small">Spinner</code></h3>
        <Spinner />
      </div>
      <div className="docui-example docui-example--spacing cui--dark docs-example--dark">
        <h3>Dark <code className="small">Spinner size:20</code></h3>
        <Spinner size={20}/>
      </div>
      <div className="docui-example docui-example--spacing cui--dark docs-example--dark">
        <h3>Dark <code className="small">Spinner size:28</code></h3>
        <Spinner size={28}/>
      </div>
      <div className="docui-example docui-example--spacing cui--dark docs-example--dark">
        <h3>Dark <code className="small">Spinner size:36</code></h3>
        <Spinner size={36}/>
      </div>
      <div className="docui-example docui-example--spacing">
        <h3>Default <code className="small">Spinner with progress size:16</code></h3>
        <Spinner size={16} percentage={65}/>
      </div>
      <div className="docui-example docui-example--spacing">
        <h3>Default <code className="small">Spinner with progress size:20</code></h3>
        <Spinner size={20} percentage={65}/>
      </div>
      <div className="docui-example docui-example--spacing">
        <h3>Default <code className="small">Spinner with progress size:28</code></h3>
        <Spinner size={28} percentage={65}/>
      </div>
      <div className="docui-example docui-example--spacing">
        <h3>Default <code className="small">Spinner with progress size:36</code></h3>
        <Spinner size={36} percentage={65}/>
      </div>
      <div className="docui-example docui-example--spacing">
        <h3>Default <code className="small">Spinner with progress without percentage size:36</code></h3>
        <Spinner size={36} percentage={65} showPercentage={false}/>
      </div>
      <div className="docui-example docui-example--spacing">
        <h3>Blue <code className="small">Spinner with progress color:blue size:16</code></h3>
        <Spinner size={16} percentage={65} color='blue'/>
      </div>
      <div className="docui-example docui-example--spacing">
        <h3>Blue <code className="small">Spinner with progress color:blue size:20</code></h3>
        <Spinner size={20} percentage={65} color='blue'/>
      </div>
      <div className="docui-example docui-example--spacing">
        <h3>Blue <code className="small">Spinner with progress color:blue size:28</code></h3>
        <Spinner size={28} percentage={65} color='blue'/>
      </div>
      <div className="docui-example docui-example--spacing">
        <h3>Blue <code className="small">Spinner with progress color:blue size:36</code></h3>
        <Spinner size={36} percentage={65} color='blue'/>
      </div>
      <div className="docui-example docui-example--spacing">
        <h3>Blue <code className="small">Spinner with progress without percentage color:blue size:36</code></h3>
        <Spinner size={36} percentage={65} color='blue' showPercentage={false}/>
      </div>
      <div className="docui-example docui-example--spacing cui--dark docs-example--dark">
        <h3>Dark <code className="small">Spinner with progress size:16</code></h3>
        <Spinner size={16} percentage={65}/>
      </div>
      <div className="docui-example docui-example--spacing cui--dark docs-example--dark">
        <h3>Dark <code className="small">Spinner with progress size:20</code></h3>
        <Spinner size={20} percentage={65}/>
      </div>
      <div className="docui-example docui-example--spacing cui--dark docs-example--dark">
        <h3>Dark <code className="small">Spinner with progress size:28</code></h3>
        <Spinner size={28} percentage={65}/>
      </div>
      <div className="docui-example docui-example--spacing cui--dark docs-example--dark">
        <h3>Dark <code className="small">Spinner with progress size:36</code></h3>
        <Spinner size={36} percentage={65}/>
      </div>
      <div className="docui-example docui-example--spacing cui--dark docs-example--dark">
        <h3>Dark <code className="small">Spinner with progress without percentage size:36</code></h3>
        <Spinner size={36} percentage={65} showPercentage={false}/>
      </div>
    </div>
  );
}

**/

exports.default = _default;
module.exports = exports["default"];